/**
 * License Agreement.
 *
 *  JBoss RichFaces - Ajax4jsf Component Library
 *
 * Copyright (C) 2007  Exadel, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 */
package org.richfaces.realworld.manager;

import java.io.Serializable;
import java.util.List;

import org.jboss.seam.ScopeType;
import org.jboss.seam.annotations.AutoCreate;
import org.jboss.seam.annotations.In;
import org.jboss.seam.annotations.Name;
import org.jboss.seam.annotations.Observer;
import org.jboss.seam.annotations.Scope;
import org.jboss.seam.annotations.security.Restrict;
import org.jboss.seam.contexts.Contexts;
import org.jboss.seam.core.Events;
import org.richfaces.realworld.domain.Image;
import org.richfaces.realworld.domain.Shelf;
import org.richfaces.realworld.domain.User;
import org.richfaces.realworld.service.Constants;
import org.richfaces.realworld.service.IShelfAction;

@Name("shelfManager")
@Scope(ScopeType.EVENT)
@AutoCreate
public class ShelfManager implements Serializable {

	private static final long serialVersionUID = 2631634926126857691L;
	
    private boolean validationSuccess = false;
    
    private List<Shelf> shelfs;

    @In IShelfAction shelfAction;

    @In User user;

    @Restrict("#{s:hasRole('admin')}")
    public void createShelf() {
        Shelf shelf = new Shelf();
        Contexts.getConversationContext().set(Constants.SHELF_VARIABLE, shelf);
    }

    @Restrict("#{s:hasRole('admin')}")
    public void addShelf(Shelf shelf) {
    	validationSuccess = true;
    	shelf.setPreDefined(false);
    	try{
    		shelfAction.addShelf(shelf);
		}catch(Exception e){
			Events.instance().raiseEvent(Constants.ADD_ERROR_EVENT, Constants.SHELF_SAVING_ERROR);
			return;
		}
        Events.instance().raiseEvent(Constants.SHELF_ADDED_EVENT, shelf);
        Events.instance().raiseEvent(Constants.CLEAR_TREE_EVENT);
    }

    public List<Shelf> getAvailableShelfs(User user) {
        return user.getShelfs();
    }

    @Restrict("#{s:hasRole('admin')}")
    public void editShelf(Shelf shelf) {
    	shelf.setPreDefined(false);
    	try{
    		shelfAction.editShelf(shelf);
		}catch(Exception e){
			Events.instance().raiseEvent(Constants.ADD_ERROR_EVENT, Constants.SHELF_SAVING_ERROR);
			return;
		}
        Events.instance().raiseEvent(Constants.SHELF_EDITED_EVENT, shelf);
    }

    @Restrict("#{s:hasRole('admin')}")
    public void deleteShelf(Shelf shelf) {
    	String pathToDelete = shelf.getPath();
    	try{
    		shelfAction.deleteShelf(shelf);
		}catch(Exception e){
			Events.instance().raiseEvent(Constants.ADD_ERROR_EVENT, Constants.SHELF_DELETING_ERROR);
			return;
		}
        Events.instance().raiseEvent(Constants.SHELF_DELETED_EVENT, shelf, pathToDelete);
        Events.instance().raiseEvent(Constants.CLEAR_TREE_EVENT);
    }

    public List<Shelf> getShelfs() {
        if (shelfs == null) {
            shelfs = shelfAction.getShelfs(user);
        }
        return shelfs;
    }

    @Observer(Constants.CLEAR_TREE_EVENT)
    public void clearShelfs() {
        shelfs = null;
    }

    public List<Image> getUnvisitedImages(Shelf shelf) {
        if (shelf.getCountUnvisitedImages() == 0) {
            shelf.setUnvisitedImages(shelfAction.getUnvisitedImages(shelf));
        }
        return shelf.getUnvisitedImages();
    }

	public boolean isValidationSuccess() {
		return validationSuccess;
	}

	public void setValidationSuccess(boolean validationSuccess) {
		this.validationSuccess = validationSuccess;
	}
}